@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# Copyright © 2016–2021 Trevor Spiteri
+# Copyright © 2016–2022 Trevor Spiteri
 
 # Copying and distribution of this file, with or without modification, are
 # permitted in any medium without royalty provided the copyright notice and this
@@ -30,11 +30,11 @@ function print_eval_check {
 # prepend "+" if TOOLCHAIN is set
 TOOLCHAIN=${TOOLCHAIN:++$TOOLCHAIN}
 
-# Test with default features and serde
+# Test with default features and num-traits and serde
 for build in "" --release; do
     print_eval_check \
         cargo $TOOLCHAIN \
         test $build \
-        --features "fail-on-warnings serde" \
+        --features "fail-on-warnings num-traits serde" \
         -p gmp-mpfr-sys -p rug
 done
