@@ -263,11 +263,13 @@ arith_prim_commut_round! {
     i32, AddI32Incomplete;
     i64, AddI64Incomplete;
     i128, AddI128Incomplete;
+    isize, AddIsizeIncomplete;
     u8, AddU8Incomplete;
     u16, AddU16Incomplete;
     u32, AddU32Incomplete;
     u64, AddU64Incomplete;
     u128, AddU128Incomplete;
+    usize, AddUsizeIncomplete;
     f32, AddF32Incomplete;
     f64, AddF64Incomplete;
 }
@@ -284,11 +286,13 @@ arith_prim_noncommut_round! {
     i32, SubI32Incomplete, SubFromI32Incomplete;
     i64, SubI64Incomplete, SubFromI64Incomplete;
     i128, SubI128Incomplete, SubFromI128Incomplete;
+    isize, SubIsizeIncomplete, SubFromIsizeIncomplete;
     u8, SubU8Incomplete, SubFromU8Incomplete;
     u16, SubU16Incomplete, SubFromU16Incomplete;
     u32, SubU32Incomplete, SubFromU32Incomplete;
     u64, SubU64Incomplete, SubFromU64Incomplete;
     u128, SubU128Incomplete, SubFromU128Incomplete;
+    usize, SubUsizeIncomplete, SubFromUsizeIncomplete;
     f32, SubF32Incomplete, SubFromF32Incomplete;
     f64, SubF64Incomplete, SubFromF64Incomplete;
 }
@@ -305,11 +309,13 @@ arith_prim_commut_round! {
     i32, MulI32Incomplete;
     i64, MulI64Incomplete;
     i128, MulI128Incomplete;
+    isize, MulIsizeIncomplete;
     u8, MulU8Incomplete;
     u16, MulU16Incomplete;
     u32, MulU32Incomplete;
     u64, MulU64Incomplete;
     u128, MulU128Incomplete;
+    usize, MulUsizeIncomplete;
     f32, MulF32Incomplete;
     f64, MulF64Incomplete;
 }
@@ -326,11 +332,13 @@ arith_prim_noncommut_round! {
     i32, DivI32Incomplete, DivFromI32Incomplete;
     i64, DivI64Incomplete, DivFromI64Incomplete;
     i128, DivI128Incomplete, DivFromI128Incomplete;
+    isize, DivIsizeIncomplete, DivFromIsizeIncomplete;
     u8, DivU8Incomplete, DivFromU8Incomplete;
     u16, DivU16Incomplete, DivFromU16Incomplete;
     u32, DivU32Incomplete, DivFromU32Incomplete;
     u64, DivU64Incomplete, DivFromU64Incomplete;
     u128, DivU128Incomplete, DivFromU128Incomplete;
+    usize, DivUsizeIncomplete, DivFromUsizeIncomplete;
     f32, DivF32Incomplete, DivFromF32Incomplete;
     f64, DivF64Incomplete, DivFromF64Incomplete;
 }
@@ -347,11 +355,13 @@ arith_prim_noncommut_round! {
     i32, RemI32Incomplete, RemFromI32Incomplete;
     i64, RemI64Incomplete, RemFromI64Incomplete;
     i128, RemI128Incomplete, RemFromI128Incomplete;
+    isize, RemIsizeIncomplete, RemFromIsizeIncomplete;
     u8, RemU8Incomplete, RemFromU8Incomplete;
     u16, RemU16Incomplete, RemFromU16Incomplete;
     u32, RemU32Incomplete, RemFromU32Incomplete;
     u64, RemU64Incomplete, RemFromU64Incomplete;
     u128, RemU128Incomplete, RemFromU128Incomplete;
+    usize, RemUsizeIncomplete, RemFromUsizeIncomplete;
     f32, RemF32Incomplete, RemFromF32Incomplete;
     f64, RemF64Incomplete, RemFromF64Incomplete;
 }
@@ -368,11 +378,13 @@ arith_prim_noncommut_round! {
     i32, PowI32Incomplete, PowFromI32Incomplete;
     i64, PowI64Incomplete, PowFromI64Incomplete;
     i128, PowI128Incomplete, PowFromI128Incomplete;
+    isize, PowIsizeIncomplete, PowFromIsizeIncomplete;
     u8, PowU8Incomplete, PowFromU8Incomplete;
     u16, PowU16Incomplete, PowFromU16Incomplete;
     u32, PowU32Incomplete, PowFromU32Incomplete;
     u64, PowU64Incomplete, PowFromU64Incomplete;
     u128, PowU128Incomplete, PowFromU128Incomplete;
+    usize, PowUsizeIncomplete, PowFromUsizeIncomplete;
     f32, PowF32Incomplete, PowFromF32Incomplete;
     f64, PowF64Incomplete, PowFromF64Incomplete;
 }
@@ -799,7 +811,9 @@ pub(crate) mod tests {
 
     #[test]
     fn check_arith_others() {
-        use crate::tests::{F32, F64, I128, I16, I32, I64, I8, U128, U16, U32, U64, U8};
+        use crate::tests::{
+            F32, F64, I128, I16, I32, I64, I8, ISIZE, U128, U16, U32, U64, U8, USIZE,
+        };
         let large = [
             Float::with_val(20, Special::Zero),
             Float::with_val(20, Special::NegZero),
@@ -839,6 +853,8 @@ pub(crate) mod tests {
             .chain(I64.iter().map(|&x| Float::with_val(20, x)))
             .chain(U128.iter().map(|&x| Float::with_val(20, x)))
             .chain(I128.iter().map(|&x| Float::with_val(20, x)))
+            .chain(USIZE.iter().map(|&x| Float::with_val(20, x)))
+            .chain(ISIZE.iter().map(|&x| Float::with_val(20, x)))
             .chain(F32.iter().map(|&x| Float::with_val(20, x)))
             .chain(F64.iter().map(|&x| Float::with_val(20, x)))
             .collect::<Vec<Float>>();
@@ -854,11 +870,13 @@ pub(crate) mod tests {
         check_others!(I32, against);
         check_others!(I64, against);
         check_others!(I128, against);
+        check_others!(ISIZE, against);
         check_others!(U8, against);
         check_others!(U16, against);
         check_others!(U32, against);
         check_others!(U64, against);
         check_others!(U128, against);
+        check_others!(USIZE, against);
         check_others!(F32, against);
         check_others!(F64, against);
         #[cfg(feature = "integer")]
