@@ -176,7 +176,7 @@ the suffix “`Assign`” replaced with “`From`”. For example the counterpar
 # #[cfg(feature = "integer")] {
 use rug::{ops::SubFrom, Integer};
 let mut rhs = Integer::from(10);
-// set rhs = 100 − rhs
+// set rhs = 100 - rhs
 rhs.sub_from(100);
 assert_eq!(rhs, 90);
 # }
@@ -272,7 +272,7 @@ a dependency inside [*Cargo.toml*]:
 
 ```toml
 [dependencies]
-rug = "1.15"
+rug = "1.16"
 ```
 
 Rug requires rustc version 1.37.0 or later.
@@ -306,7 +306,7 @@ selectively, you can add the dependency like this to [*Cargo.toml*]:
 
 ```toml
 [dependencies.rug]
-version = "1.15"
+version = "1.16"
 default-features = false
 features = ["integer", "float", "rand"]
 ```
@@ -346,7 +346,7 @@ updated to an incompatible newer version.
 [sys]: gmp_mpfr_sys
 */
 #![warn(missing_docs)]
-#![doc(html_root_url = "https://docs.rs/rug/~1.15")]
+#![doc(html_root_url = "https://docs.rs/rug/~1.16")]
 #![doc(html_logo_url = "data:image/svg+xml;base64,
 PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPCEtLSBDcmVhdGVkIHdpdGggSW5rc2NhcGUgKGh0dHA6Ly93
 d3cuaW5rc2NhcGUub3JnLykgLS0+Cjxzdmcgd2lkdGg9IjEyOCIgaGVpZ2h0PSIxMjgiIHZlcnNpb249IjEuMSIgdmlld0JveD0i
@@ -601,7 +601,7 @@ mod static_assertions {
 mod tests {
     #[cfg(any(feature = "rational", feature = "float"))]
     use core::{f32, f64};
-    use core::{i128, i16, i32, i64, i8, u128, u16, u32, u64, u8};
+    use core::{i128, i16, i32, i64, i8, isize, u128, u16, u32, u64, u8, usize};
 
     pub const U8: &[u8] = &[0, 1, 100, 101, i8::MAX as u8 + 1, u8::MAX];
     pub const I8: &[i8] = &[i8::MIN, -101, -100, -1, 0, 1, 100, 101, i8::MAX];
@@ -663,6 +663,8 @@ mod tests {
         u64::MAX as i128 + 1,
         i128::MAX,
     ];
+    pub const USIZE: &[usize] = &[0, 1, 1000, 1001, isize::MAX as usize + 1, usize::MAX];
+    pub const ISIZE: &[isize] = &[isize::MIN, -1001, -1000, -1, 0, 1, 1000, 1001, isize::MAX];
     #[cfg(any(feature = "rational", feature = "float"))]
     pub const F32: &[f32] = &[
         -f32::NAN,
